@@ -1,35 +1,18 @@
-import asyncio
 import mimetypes
 import os
 from datetime import datetime
-from functools import partial, wraps
 from hashlib import md5
 from os import PathLike
-from os import access as os_access
 from pathlib import Path
 from typing import Callable, List, Optional, Union
 
-from aiofiles import open as a_open
-from aiofiles import os as a_os
-from aiofiles.os import path as a_path
+import aiofiles
+import aiofiles.os
+import aiofiles.ospath
 
 _FILE_BLOCK_SIZE = 64 * 1024
 
 
-def a_wrap(func):
-    @wraps(func)
-    async def run(*args, loop=None, executor=None, **kwargs):
-        if loop is None:
-            loop = asyncio.get_event_loop()
-        pfunc = partial(func, *args, **kwargs)
-        return await loop.run_in_executor(executor, pfunc)
-
-    return run
-
-
-a_access = a_wrap(os_access)
-
-
 class ASGIMiddlewarePath:
     def __init__(self, path: Union[PathLike, str]):
         if not isinstance(path, Path):
@@ -47,7 +30,9 @@ class ASGIMiddlewarePath:
         return self.parts[: path.count] == path.parts
 
     async def accessible(self) -> bool:
-        if await a_path.isfile(self.path) and await a_access(self.path, os.R_OK):
+        if await aiofiles.ospath.isfile(self.path) and await aiofiles.os.access(
+            self.path, os.R_OK
+        ):
             return True
 
         return False
@@ -115,7 +100,7 @@ class ASGIMiddlewareStaticFile:
             encoding = encoding.encode("utf-8")
         else:
             encoding = b""
-        stat_result = await a_os.stat(abs_path)
+        stat_result = await aiofiles.os.stat(abs_path)
         file_size = str(stat_result.st_size).encode("utf-8")
         last_modified = (
             datetime.fromtimestamp(stat_result.st_mtime)
@@ -149,7 +134,7 @@ class ASGIMiddlewareStaticFile:
             return
 
         # send file
-        async with a_open(abs_path, mode="rb") as f:
+        async with aiofiles.open(abs_path, mode="rb") as f:
             more_body = True
             while more_body:
                 data = await f.read(_FILE_BLOCK_SIZE)
